@@ -162,7 +162,7 @@ class FunctionalTests(testtools.TestCase):
 
     def test_httplib_https(self):
         '''Test for `httplib.HTTPSConnection`.'''
-        expect = {'SEVERITY': {'MEDIUM': 1}, 'CONFIDENCE': {'HIGH': 1}}
+        expect = {'SEVERITY': {'MEDIUM': 3}, 'CONFIDENCE': {'HIGH': 3}}
         self.check_example('httplib_https.py', expect)
 
     def test_imports_aliases(self):
@@ -228,7 +228,8 @@ class FunctionalTests(testtools.TestCase):
 
     def test_os_popen(self):
         '''Test for `os.popen`.'''
-        expect = {'SEVERITY': {'MEDIUM': 7}, 'CONFIDENCE': {'MEDIUM': 7}}
+        expect = {'SEVERITY': {'LOW': 7, 'MEDIUM': 1, 'HIGH': 1},
+                  'CONFIDENCE': {'HIGH': 9}}
         self.check_example('os-popen.py', expect)
 
     def test_os_spawn(self):
@@ -243,7 +244,7 @@ class FunctionalTests(testtools.TestCase):
 
     def test_os_system(self):
         '''Test for `os.system`.'''
-        expect = {'SEVERITY': {'MEDIUM': 1}, 'CONFIDENCE': {'MEDIUM': 1}}
+        expect = {'SEVERITY': {'LOW': 1}, 'CONFIDENCE': {'HIGH': 1}}
         self.check_example('os_system.py', expect)
 
     def test_pickle(self):
@@ -256,7 +257,7 @@ class FunctionalTests(testtools.TestCase):
 
     def test_popen_wrappers(self):
         '''Test the `popen2` and `commands` modules.'''
-        expect = {'SEVERITY': {'MEDIUM': 7}, 'CONFIDENCE': {'MEDIUM': 7}}
+        expect = {'SEVERITY': {'MEDIUM': 7}, 'CONFIDENCE': {'HIGH': 7}}
         self.check_example('popen_wrappers.py', expect)
 
     def test_random_module(self):
@@ -297,14 +298,14 @@ class FunctionalTests(testtools.TestCase):
     def test_subprocess_shell(self):
         '''Test for `subprocess.Popen` with `shell=True`.'''
         expect = {
-            'SEVERITY': {'HIGH': 2, 'MEDIUM': 2, 'LOW': 12},
-            'CONFIDENCE': {'HIGH': 16}
+            'SEVERITY': {'HIGH': 3, 'MEDIUM': 2, 'LOW': 12},
+            'CONFIDENCE': {'HIGH': 17}
         }
         self.check_example('subprocess_shell.py', expect)
 
     def test_urlopen(self):
         '''Test for dangerous URL opening.'''
-        expect = {'SEVERITY': {'MEDIUM': 6}, 'CONFIDENCE': {'HIGH': 6}}
+        expect = {'SEVERITY': {'MEDIUM': 14}, 'CONFIDENCE': {'HIGH': 14}}
         self.check_example('urlopen.py', expect)
 
     def test_utils_shell(self):
@@ -319,7 +320,7 @@ class FunctionalTests(testtools.TestCase):
         '''Test for wildcard injection in shell commands.'''
         expect = {
             'SEVERITY': {'HIGH': 4, 'MEDIUM':4, 'LOW': 6},
-            'CONFIDENCE': {'MEDIUM': 8, 'HIGH': 6}
+            'CONFIDENCE': {'MEDIUM': 5, 'HIGH': 9}
         }
         self.check_example('wildcard-injection.py', expect)
 
@@ -476,7 +477,7 @@ class FunctionalTests(testtools.TestCase):
               "filename": "%s/examples/flask_debug.py",
               "issue_confidence": "MEDIUM",
               "issue_severity": "HIGH",
-              "issue_text": "A Flask app appears to be run with debug=True ..",
+              "issue_text": "A Flask app appears to be run with debug=True, which exposes the Werkzeug debugger and allows the execution of arbitrary code.",
               "line_number": 10,
               "line_range": [
                 10
@@ -490,4 +491,4 @@ class FunctionalTests(testtools.TestCase):
         self.b_mgr.populate_baseline(json)
         self.run_example('flask_debug.py')
         self.assertEqual(len(self.b_mgr.baseline), 1)
-        self.assertEqual(self.b_mgr.get_issue_list(), [])
+        self.assertEqual(self.b_mgr.get_issue_list(), {})
